@@ -6,7 +6,7 @@ export FLASH_KERNEL_SKIP=1
 export DEBIAN_FRONTEND=noninteractive
 
 # list all packages needed for a generic ubuntu touch initrd here
-INCHROOTPKGS="initramfs-tools-ubuntu-touch dctrl-tools lxc-android-config"
+INCHROOTPKGS="initramfs-tools-ubuntu-touch dctrl-tools"
 
 MIRROR=$(grep "^deb " /etc/apt/sources.list|head -1|cut -d' ' -f2)
 RELEASE=$(lsb_release -cs)
@@ -48,6 +48,12 @@ chmod a+rx $ROOT/sbin/initctl
 fakeroot -i chroot.save fakechroot chroot $ROOT apt-get -y update
 fakeroot -i chroot.save fakechroot chroot $ROOT apt-get -y install $INCHROOTPKGS
 
+# remove unwanted udev rules (temporary hack until we can install lxc-android-config
+# FIXME !!!
+rm $ROOT/lib/udev/rules.d/50-firmware.rules || true
+rm $ROOT/lib/udev/rules.d/60-persistent-v4l.rules || true
+rm $ROOT/lib/udev/rules.d/90-alsa-ucm.rules || true
+
 VER=$(fakeroot -i chroot.save fakechroot chroot ${ROOT} grep-status -P initramfs-tools-ubuntu-touch -s Version| sed  's/^.* //')
 export LD_LIBRARY_PATH=/lib/arm-linux-gnueabihf
 fakeroot -i chroot.save fakechroot chroot $ROOT update-initramfs -c -ktouch-$VER -v
